Crate tectonic_bridge_freetype2

Crate tectonic_bridge_freetype2 

This crate exists to export the FreeType2 C API into the Cargo framework, as well as provide bindings to other tectonic crates.

Modules

tables
Recognized tables that can be safely loaded by Rust code

Structs

BBox
EncodingId
A TrueType encoding ID
Error
An error code returned by freetype.
Face
A typographic face - the combination of a general typeface and a style.
Glyph
A generic glyph image.
GlyphMetrics
GlyphSlot
A glyph loaded into a faces glyph slot.
LanguageId
A TrueType language ID
LoadFlags
Glyph loading flags, to control whether some steps are performed, or change loading modes (such as horizontal or vertical text).
Outline
PlatformId
A TrueType platform ID
SfntName
A font name table value
Vector

Enums

BBoxMode
GlyphFormat
KerningMode
SfntTag
Enumeration of ‘well known’ sfnt tables, recognized by freetype natively.
TableTag
A tag representing a specific table to load.

Traits

Table
Trait for types that represent different sfnt tables you can read from a Face.

Functions

init
Initialize FreeType. This function will panic if initialization fails.

Type Aliases

Fixed