This crate exists to export the FreeType2 C API into the Cargo framework, as well as provide
bindings to other tectonic crates.
Modules
- tables
- Recognized tables that can be safely loaded by Rust code
Structs
- BBox
- Encoding
Id - A TrueType encoding ID
- Error
- An error code returned by freetype.
- Face
- A typographic face - the combination of a general typeface and a style.
- Glyph
- A generic glyph image.
- Glyph
Metrics - Glyph
Slot - A glyph loaded into a faces glyph slot.
- Language
Id - A TrueType language ID
- Load
Flags - Glyph loading flags, to control whether some steps are performed, or change loading modes (such as horizontal or vertical text).
- Outline
- Platform
Id - A TrueType platform ID
- Sfnt
Name - A font name table value
- Vector
Enums
- BBox
Mode - Glyph
Format - Kerning
Mode - SfntTag
- Enumeration of ‘well known’ sfnt tables, recognized by freetype natively.
- Table
Tag - A tag representing a specific table to load.
Traits
Functions
- init
- Initialize FreeType. This function will panic if initialization fails.